"""Check for correct behavior when psf-load-responses flag is set
but there is no '_responses' fixture specified in the data file.
"""


def test_psf_response_not_in_datafile(pytester):
    # create the test code file
    test_file_path = pytester.copy_example("example_test_psf_response_not_in_datafile_tester.py")
    test_file_path.rename("test_psf_response_not_in_datafile_tester.py")

    # create the data file
    pytester.copy_example("data_psf_response_not_in_datafile_tester.yaml")

    result = pytester.runpytest("-k", "test_psf_response_not_in_datafile", "-v", "--psf-load-responses")

    result.assert_outcomes(passed=2)



"""Test indirect fixture loading"""

import pytest

# skip these tests if the responses module is not present
responses = pytest.importorskip("responses")


def test_load_native_responses_failure_bad_filename(pytester: pytest.Pytester):
    # create the test code file
    test_file_path = pytester.copy_example("example_test_native_responses_failure_tester.py")
    test_file_path.rename("test_native_responses_failure_tester.py")

    # create the data file and native Responses file
    pytester.copy_example("data_native_responses_failure_tester_bad_filename.yaml")

    result = pytester.runpytest("-v", "--psf-load-responses")

    result.assert_outcomes(errors=1)


def test_load_native_responses_failure_duplicate_files(pytester: pytest.Pytester):
    # create the test code file
    test_file_path = pytester.copy_example("example_test_native_responses_failure_tester.py")
    test_file_path.rename("test_native_responses_failure_tester.py")

    # create the data file and two copies of the native Responses file
    pytester.copy_example("data_native_responses_failure_tester_duplicate_files.yaml")

    # first copy goes into subdir
    datafile_path = pytester.copy_example("responses_replay_data.yaml")
    subdir_path = datafile_path.parent / "subdir"
    subdir_path.mkdir()
    datafile_path.rename(subdir_path / datafile_path.name)

    # second copy at top level
    pytester.copy_example("responses_replay_data.yaml")

    result = pytester.runpytest("-v", "--psf-load-responses")

    result.assert_outcomes(errors=1)



import pytest
import requests


@pytest.mark.skipif('not config.getoption("psf-load-responses", False)')
def test_native_responses_failure_tester(psf_responses, psf_expected_result, target_url):
    with psf_expected_result as expected_result:
        req_result = requests.get(target_url)
        req_result.raise_for_status()
        assert req_result.text == expected_result



def test_data_file_not_dict(pytester):
    test_file_path = pytester.copy_example("example_test_data_file_not_dict_tester.py")
    test_file_path.rename("test_data_file_not_dict_tester.py")

    # create the data files
    pytester.copy_example("data_data_file_not_dict_tester.yaml")

    result = pytester.runpytest("-k", "test_data_file_not_dict_tester", "-v")

    result.assert_outcomes(errors=1)
